/// https://tailwindcss.com/docs/flex-basis
pub struct FlexSystem {}
